Documentation
¶
Overview ¶
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Index ¶
- Constants
- Variables
- func RegisterMsgServer(s grpc.ServiceRegistrar, srv MsgServer)
- func RegisterQueryServer(s grpc.ServiceRegistrar, srv QueryServer)
- type ChainParams
- func (*ChainParams) Descriptor() ([]byte, []int)deprecated
- func (x *ChainParams) GetBorChainId() string
- func (x *ChainParams) GetHeimdallChainId() string
- func (x *ChainParams) GetPolTokenAddress() string
- func (x *ChainParams) GetRootChainAddress() string
- func (x *ChainParams) GetSlashManagerAddress() string
- func (x *ChainParams) GetStakingInfoAddress() string
- func (x *ChainParams) GetStakingManagerAddress() string
- func (x *ChainParams) GetStateReceiverAddress() string
- func (x *ChainParams) GetStateSenderAddress() string
- func (x *ChainParams) GetValidatorSetAddress() string
- func (*ChainParams) ProtoMessage()
- func (x *ChainParams) ProtoReflect() protoreflect.Message
- func (x *ChainParams) Reset()
- func (x *ChainParams) String() string
- type GenesisState
- type MsgClient
- type MsgServer
- type MsgUpdateParams
- func (*MsgUpdateParams) Descriptor() ([]byte, []int)deprecated
- func (x *MsgUpdateParams) GetAuthority() string
- func (x *MsgUpdateParams) GetParams() *Params
- func (*MsgUpdateParams) ProtoMessage()
- func (x *MsgUpdateParams) ProtoReflect() protoreflect.Message
- func (x *MsgUpdateParams) Reset()
- func (x *MsgUpdateParams) String() string
- type MsgUpdateParamsResponse
- type Params
- func (*Params) Descriptor() ([]byte, []int)deprecated
- func (x *Params) GetBorChainTxConfirmations() uint64
- func (x *Params) GetChainParams() *ChainParams
- func (x *Params) GetMainChainTxConfirmations() uint64
- func (*Params) ProtoMessage()
- func (x *Params) ProtoReflect() protoreflect.Message
- func (x *Params) Reset()
- func (x *Params) String() string
- type QueryClient
- type QueryParamsRequest
- type QueryParamsResponse
- func (*QueryParamsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *QueryParamsResponse) GetParams() *Params
- func (*QueryParamsResponse) ProtoMessage()
- func (x *QueryParamsResponse) ProtoReflect() protoreflect.Message
- func (x *QueryParamsResponse) Reset()
- func (x *QueryParamsResponse) String() string
- type QueryServer
- type UnimplementedMsgServer
- type UnimplementedQueryServer
- type UnsafeMsgServer
- type UnsafeQueryServer
Constants ¶
const (
Msg_UpdateParams_FullMethodName = "/heimdallv2.chainmanager.Msg/UpdateParams"
)
const (
Query_GetChainManagerParams_FullMethodName = "/heimdallv2.chainmanager.Query/GetChainManagerParams"
)
Variables ¶
var File_heimdallv2_chainmanager_chainmanager_proto protoreflect.FileDescriptor
var File_heimdallv2_chainmanager_genesis_proto protoreflect.FileDescriptor
var File_heimdallv2_chainmanager_query_proto protoreflect.FileDescriptor
var File_heimdallv2_chainmanager_tx_proto protoreflect.FileDescriptor
var Msg_ServiceDesc = grpc.ServiceDesc{ ServiceName: "heimdallv2.chainmanager.Msg", HandlerType: (*MsgServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "UpdateParams", Handler: _Msg_UpdateParams_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "heimdallv2/chainmanager/tx.proto", }
Msg_ServiceDesc is the grpc.ServiceDesc for Msg service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var Query_ServiceDesc = grpc.ServiceDesc{ ServiceName: "heimdallv2.chainmanager.Query", HandlerType: (*QueryServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetChainManagerParams", Handler: _Query_GetChainManagerParams_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "heimdallv2/chainmanager/query.proto", }
Query_ServiceDesc is the grpc.ServiceDesc for Query service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterMsgServer ¶
func RegisterMsgServer(s grpc.ServiceRegistrar, srv MsgServer)
func RegisterQueryServer ¶
func RegisterQueryServer(s grpc.ServiceRegistrar, srv QueryServer)
Types ¶
type ChainParams ¶
type ChainParams struct {
BorChainId string `protobuf:"bytes,1,opt,name=bor_chain_id,json=borChainId,proto3" json:"bor_chain_id,omitempty"`
HeimdallChainId string `protobuf:"bytes,2,opt,name=heimdall_chain_id,json=heimdallChainId,proto3" json:"heimdall_chain_id,omitempty"`
PolTokenAddress string `protobuf:"bytes,3,opt,name=pol_token_address,json=polTokenAddress,proto3" json:"pol_token_address,omitempty"`
StakingManagerAddress string `` /* 126-byte string literal not displayed */
SlashManagerAddress string `protobuf:"bytes,5,opt,name=slash_manager_address,json=slashManagerAddress,proto3" json:"slash_manager_address,omitempty"`
RootChainAddress string `protobuf:"bytes,6,opt,name=root_chain_address,json=rootChainAddress,proto3" json:"root_chain_address,omitempty"`
StakingInfoAddress string `protobuf:"bytes,7,opt,name=staking_info_address,json=stakingInfoAddress,proto3" json:"staking_info_address,omitempty"`
StateSenderAddress string `protobuf:"bytes,8,opt,name=state_sender_address,json=stateSenderAddress,proto3" json:"state_sender_address,omitempty"`
StateReceiverAddress string `protobuf:"bytes,9,opt,name=state_receiver_address,json=stateReceiverAddress,proto3" json:"state_receiver_address,omitempty"`
ValidatorSetAddress string `protobuf:"bytes,10,opt,name=validator_set_address,json=validatorSetAddress,proto3" json:"validator_set_address,omitempty"`
// contains filtered or unexported fields
}
func (*ChainParams) Descriptor
deprecated
func (*ChainParams) Descriptor() ([]byte, []int)
Deprecated: Use ChainParams.ProtoReflect.Descriptor instead.
func (*ChainParams) GetBorChainId ¶
func (x *ChainParams) GetBorChainId() string
func (*ChainParams) GetHeimdallChainId ¶
func (x *ChainParams) GetHeimdallChainId() string
func (*ChainParams) GetPolTokenAddress ¶
func (x *ChainParams) GetPolTokenAddress() string
func (*ChainParams) GetRootChainAddress ¶
func (x *ChainParams) GetRootChainAddress() string
func (*ChainParams) GetSlashManagerAddress ¶
func (x *ChainParams) GetSlashManagerAddress() string
func (*ChainParams) GetStakingInfoAddress ¶
func (x *ChainParams) GetStakingInfoAddress() string
func (*ChainParams) GetStakingManagerAddress ¶
func (x *ChainParams) GetStakingManagerAddress() string
func (*ChainParams) GetStateReceiverAddress ¶
func (x *ChainParams) GetStateReceiverAddress() string
func (*ChainParams) GetStateSenderAddress ¶
func (x *ChainParams) GetStateSenderAddress() string
func (*ChainParams) GetValidatorSetAddress ¶
func (x *ChainParams) GetValidatorSetAddress() string
func (*ChainParams) ProtoMessage ¶
func (*ChainParams) ProtoMessage()
func (*ChainParams) ProtoReflect ¶
func (x *ChainParams) ProtoReflect() protoreflect.Message
func (*ChainParams) Reset ¶
func (x *ChainParams) Reset()
func (*ChainParams) String ¶
func (x *ChainParams) String() string
type GenesisState ¶
type GenesisState struct {
Params *Params `protobuf:"bytes,1,opt,name=params,proto3" json:"params,omitempty"`
// contains filtered or unexported fields
}
func (*GenesisState) Descriptor
deprecated
func (*GenesisState) Descriptor() ([]byte, []int)
Deprecated: Use GenesisState.ProtoReflect.Descriptor instead.
func (*GenesisState) GetParams ¶
func (x *GenesisState) GetParams() *Params
func (*GenesisState) ProtoMessage ¶
func (*GenesisState) ProtoMessage()
func (*GenesisState) ProtoReflect ¶
func (x *GenesisState) ProtoReflect() protoreflect.Message
func (*GenesisState) Reset ¶
func (x *GenesisState) Reset()
func (*GenesisState) String ¶
func (x *GenesisState) String() string
type MsgClient ¶
type MsgClient interface {
// UpdateParams defines a governance operation for updating the x/chainmanager
// module parameters. The authority is defined in the keeper.
UpdateParams(ctx context.Context, in *MsgUpdateParams, opts ...grpc.CallOption) (*MsgUpdateParamsResponse, error)
}
MsgClient is the client API for Msg service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewMsgClient ¶
func NewMsgClient(cc grpc.ClientConnInterface) MsgClient
type MsgServer ¶
type MsgServer interface {
// UpdateParams defines a governance operation for updating the x/chainmanager
// module parameters. The authority is defined in the keeper.
UpdateParams(context.Context, *MsgUpdateParams) (*MsgUpdateParamsResponse, error)
// contains filtered or unexported methods
}
MsgServer is the server API for Msg service. All implementations must embed UnimplementedMsgServer for forward compatibility
type MsgUpdateParams ¶
type MsgUpdateParams struct {
Authority string `protobuf:"bytes,1,opt,name=authority,proto3" json:"authority,omitempty"`
Params *Params `protobuf:"bytes,2,opt,name=params,proto3" json:"params,omitempty"`
// contains filtered or unexported fields
}
func (*MsgUpdateParams) Descriptor
deprecated
func (*MsgUpdateParams) Descriptor() ([]byte, []int)
Deprecated: Use MsgUpdateParams.ProtoReflect.Descriptor instead.
func (*MsgUpdateParams) GetAuthority ¶
func (x *MsgUpdateParams) GetAuthority() string
func (*MsgUpdateParams) GetParams ¶
func (x *MsgUpdateParams) GetParams() *Params
func (*MsgUpdateParams) ProtoMessage ¶
func (*MsgUpdateParams) ProtoMessage()
func (*MsgUpdateParams) ProtoReflect ¶
func (x *MsgUpdateParams) ProtoReflect() protoreflect.Message
func (*MsgUpdateParams) Reset ¶
func (x *MsgUpdateParams) Reset()
func (*MsgUpdateParams) String ¶
func (x *MsgUpdateParams) String() string
type MsgUpdateParamsResponse ¶
type MsgUpdateParamsResponse struct {
// contains filtered or unexported fields
}
func (*MsgUpdateParamsResponse) Descriptor
deprecated
func (*MsgUpdateParamsResponse) Descriptor() ([]byte, []int)
Deprecated: Use MsgUpdateParamsResponse.ProtoReflect.Descriptor instead.
func (*MsgUpdateParamsResponse) ProtoMessage ¶
func (*MsgUpdateParamsResponse) ProtoMessage()
func (*MsgUpdateParamsResponse) ProtoReflect ¶
func (x *MsgUpdateParamsResponse) ProtoReflect() protoreflect.Message
func (*MsgUpdateParamsResponse) Reset ¶
func (x *MsgUpdateParamsResponse) Reset()
func (*MsgUpdateParamsResponse) String ¶
func (x *MsgUpdateParamsResponse) String() string
type Params ¶
type Params struct {
ChainParams *ChainParams `protobuf:"bytes,1,opt,name=chain_params,json=chainParams,proto3" json:"chain_params,omitempty"`
MainChainTxConfirmations uint64 `` /* 138-byte string literal not displayed */
BorChainTxConfirmations uint64 `` /* 135-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Params) Descriptor
deprecated
func (*Params) GetBorChainTxConfirmations ¶
func (*Params) GetChainParams ¶
func (x *Params) GetChainParams() *ChainParams
func (*Params) GetMainChainTxConfirmations ¶
func (*Params) ProtoMessage ¶
func (*Params) ProtoMessage()
func (*Params) ProtoReflect ¶
func (x *Params) ProtoReflect() protoreflect.Message
type QueryClient ¶
type QueryClient interface {
// GetChainManagerParams queries the parameters of x/chainmanager module
GetChainManagerParams(ctx context.Context, in *QueryParamsRequest, opts ...grpc.CallOption) (*QueryParamsResponse, error)
}
QueryClient is the client API for Query service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewQueryClient ¶
func NewQueryClient(cc grpc.ClientConnInterface) QueryClient
type QueryParamsRequest ¶
type QueryParamsRequest struct {
// contains filtered or unexported fields
}
func (*QueryParamsRequest) Descriptor
deprecated
func (*QueryParamsRequest) Descriptor() ([]byte, []int)
Deprecated: Use QueryParamsRequest.ProtoReflect.Descriptor instead.
func (*QueryParamsRequest) ProtoMessage ¶
func (*QueryParamsRequest) ProtoMessage()
func (*QueryParamsRequest) ProtoReflect ¶
func (x *QueryParamsRequest) ProtoReflect() protoreflect.Message
func (*QueryParamsRequest) Reset ¶
func (x *QueryParamsRequest) Reset()
func (*QueryParamsRequest) String ¶
func (x *QueryParamsRequest) String() string
type QueryParamsResponse ¶
type QueryParamsResponse struct {
Params *Params `protobuf:"bytes,1,opt,name=params,proto3" json:"params,omitempty"`
// contains filtered or unexported fields
}
func (*QueryParamsResponse) Descriptor
deprecated
func (*QueryParamsResponse) Descriptor() ([]byte, []int)
Deprecated: Use QueryParamsResponse.ProtoReflect.Descriptor instead.
func (*QueryParamsResponse) GetParams ¶
func (x *QueryParamsResponse) GetParams() *Params
func (*QueryParamsResponse) ProtoMessage ¶
func (*QueryParamsResponse) ProtoMessage()
func (*QueryParamsResponse) ProtoReflect ¶
func (x *QueryParamsResponse) ProtoReflect() protoreflect.Message
func (*QueryParamsResponse) Reset ¶
func (x *QueryParamsResponse) Reset()
func (*QueryParamsResponse) String ¶
func (x *QueryParamsResponse) String() string
type QueryServer ¶
type QueryServer interface {
// GetChainManagerParams queries the parameters of x/chainmanager module
GetChainManagerParams(context.Context, *QueryParamsRequest) (*QueryParamsResponse, error)
// contains filtered or unexported methods
}
QueryServer is the server API for Query service. All implementations must embed UnimplementedQueryServer for forward compatibility
type UnimplementedMsgServer ¶
type UnimplementedMsgServer struct {
}
UnimplementedMsgServer must be embedded to have forward compatible implementations.
func (UnimplementedMsgServer) UpdateParams ¶
func (UnimplementedMsgServer) UpdateParams(context.Context, *MsgUpdateParams) (*MsgUpdateParamsResponse, error)
type UnimplementedQueryServer ¶
type UnimplementedQueryServer struct {
}
UnimplementedQueryServer must be embedded to have forward compatible implementations.
func (UnimplementedQueryServer) GetChainManagerParams ¶
func (UnimplementedQueryServer) GetChainManagerParams(context.Context, *QueryParamsRequest) (*QueryParamsResponse, error)
type UnsafeMsgServer ¶
type UnsafeMsgServer interface {
// contains filtered or unexported methods
}
UnsafeMsgServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MsgServer will result in compilation errors.
type UnsafeQueryServer ¶
type UnsafeQueryServer interface {
// contains filtered or unexported methods
}
UnsafeQueryServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to QueryServer will result in compilation errors.